"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.SnsEventNotifier = void 0;
const optional_1 = require("@othree.io/optional");
const client_sns_1 = require("@aws-sdk/client-sns");
function SnsEventNotifier(snsClient, configuration) {
    return {
        publish: (event, state) => __awaiter(this, void 0, void 0, function* () {
            const tryResult = yield (0, optional_1.TryAsync)(() => __awaiter(this, void 0, void 0, function* () {
                const command = new client_sns_1.PublishCommand({
                    Message: JSON.stringify({
                        event: event,
                        state: state
                    }),
                    MessageAttributes: {
                        bc: {
                            DataType: 'String',
                            StringValue: configuration.BoundedContext
                        },
                        eventType: {
                            DataType: 'String',
                            StringValue: event.type.toString()
                        }
                    },
                    MessageGroupId: configuration.IsFifo ? event.contextId.toString() : undefined,
                    TopicArn: configuration.TopicArn
                });
                console.debug('Publishing event to sns', command.input);
                return snsClient.send(command);
            }));
            return tryResult.map(response => {
                console.log('Event published to sns. MessageId: ', response.MessageId);
                return true;
            });
        })
    };
}
exports.SnsEventNotifier = SnsEventNotifier;
module.exports = { SnsEventNotifier };
//# sourceMappingURL=sns-event-notifier.js.map